[git] GnuPG - branch, master, updated. gnupg-2.2.7-201-g1bfe766

[email protected] (by Werner Koch)
Newsgroups gmane.comp.encryption.gpg.cvs
Message-ID <[email protected]>
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "The GNU Privacy Guard".

The branch, master has been updated
       via  1bfe766bcf3959135333900934f1a15c9b96c3cf (commit)
      from  420dc2b49ad816bdd27b40db45d900551c71476f (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit 1bfe766bcf3959135333900934f1a15c9b96c3cf
Author: Werner Koch <[email protected]>
Date:   Wed Aug 29 15:14:29 2018 +0200

    gpg: Explain error message in key generation with --batch
    
    * g10/keygen.c (generate_keypair): Show more info.
    --
    
    GnuPG-bug-id: 3912
    Signed-off-by: Werner Koch <[email protected]>

diff --git a/g10/keygen.c b/g10/keygen.c
index fbead10..8177040 100644
--- a/g10/keygen.c
+++ b/g10/keygen.c
@@ -4238,8 +4238,10 @@ generate_keypair (ctrl_t ctrl, int full, const char *fname,
 
   if (opt.batch && card_serialno)
     {
       /* We don't yet support unattended key generation. */
       log_error (_("can't do this in batch mode\n"));
+      print_further_info ("key generation with card serial number");
       return;
     }
 

-----------------------------------------------------------------------

Summary of changes:
 g10/keygen.c | 4 +++-
@@ -4238,8 +4238,10 @@ generate_keypair (ctrl_t ctrl, int full, const char *fname,
   if (opt.batch && card_serialno)
     {
-      /* We don't yet support unattended key generation. */
+      /* We don't yet support unattended key generation with a card
+       * serial number. */
       log_error (_("can't do this in batch mode\n"));
 1 file changed, 3 insertions(+), 1 deletion(-)


hooks/post-receive
-- 
The GNU Privacy Guard
http://git.gnupg.org
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.